@@ -1,10 +1,13 @@
 import datetime
 import sys
 
+import requests
+
 from je_api_testka.requests_wrapper.requests_http_method_wrapper import api_tester_method
 from requests.structures import CaseInsensitiveDict
 
 from je_api_testka.utils.exception.api_test_exceptions import APITesterGetDataException
+from je_api_testka.utils.exception.api_test_exceptions import APITesterExecuteException
 from je_api_testka.utils.get_data_strcture.get_api_data import get_api_response_data
 
 from je_api_testka.utils.exception.api_test_eceptions_tag import api_test_get_data_error_message
@@ -41,7 +44,7 @@ exception_message_dict = {
 }
 
 
-def get_response(response, start_time, end_time):
+def get_response(response, start_time, end_time) -> dict:
     try:
         return get_api_response_data(response, start_time, end_time)
     except APITesterGetDataException:
@@ -50,26 +53,32 @@ def get_response(response, start_time, end_time):
 
 def test_api_method(http_method: str, test_url: str,
                     soap: bool = False, record_request_info: bool = True,
-                    clean_record: bool = False, result_check_dict: dict = None, **kwargs):
+                    clean_record: bool = False, result_check_dict: dict = None, **kwargs)\
+        -> (requests.Response, dict):
     try:
-        start_time = datetime.datetime.now()
-        if soap is False:
-            response = api_tester_method(http_method, test_url=test_url, **kwargs)
-        else:
-            headers = CaseInsensitiveDict()
-            headers["Content-Type"] = "application/soap+xml"
-            return test_api_method(http_method, test_url=test_url, headers=headers, **kwargs)
-        end_time = datetime.datetime.now()
-        response_data = get_response(response, start_time, end_time)
-        if record_request_info:
-            test_record.record_list.append(response_data)
-        if clean_record:
-            test_record.clean_record()
-        if result_check_dict is None:
-            return {"response": response, "response_data": response_data}
-        else:
-            check_result(response_data, result_check_dict)
-            return {"response": response, "response_data": response_data}
+        try:
+            start_time = datetime.datetime.now()
+            if soap is False:
+                response = api_tester_method(http_method, test_url=test_url, **kwargs)
+            else:
+                headers = CaseInsensitiveDict()
+                headers["Content-Type"] = "application/soap+xml"
+                return test_api_method(http_method, test_url=test_url, headers=headers, **kwargs)
+            end_time = datetime.datetime.now()
+            response_data = get_response(response, start_time, end_time)
+            if clean_record:
+                test_record.clean_record()
+            if result_check_dict is None:
+                if record_request_info:
+                    test_record.record_list.append(response_data)
+                return {"response": response, "response_data": response_data}
+            else:
+                check_result(response_data, result_check_dict)
+                if record_request_info:
+                    test_record.record_list.append(response_data)
+                return {"response": response, "response_data": response_data}
+        except APITesterExecuteException as error:
+            raise repr(error)
     except Exception as error:
         print(repr(error), file=sys.stderr)
         test_record.error_record_list.append([
